@@ -53,7 +53,7 @@ def handle_discriminator(
         return
 
     try:
-        validator.resolver.resolve(ref)
+        validator._validate_reference(ref=ref, instance=instance)
     except:
         yield ValidationError(
             f"{instance!r} reference {ref!r} could not be resolved",
@@ -187,10 +187,7 @@ def read_required(
             prop_schema = schema.get("properties", {}).get(property)
             if prop_schema:
                 write_only = prop_schema.get("writeOnly", False)
-                if (
-                    getattr(validator, "read", True)
-                    and write_only
-                ):
+                if getattr(validator, "read", True) and write_only:
                     continue
             yield ValidationError(f"{property!r} is a required property")
 
@@ -267,4 +264,5 @@ def not_implemented(
     instance: Any,
     schema: Mapping[Hashable, Any],
 ) -> Iterator[ValidationError]:
-    pass
+    return
+    yield
